@@ -36,8 +36,12 @@
 #include <kcmdlineargs.h>
 #include <kio/netaccess.h>
 #include "MainWindow/Window.h"
-#include "X11/X.h"
 
+#ifdef Q_WS_X11
+#include "X11/X.h"
+#endif
+
+#include <QTextCodec>
 #include "Utilities/JpeglibWithFix.h"
 
 extern "C" {
